function Anton2D()

close all;

% Properties of the unmodulated RF
cx = 0.0;
cy = 0.0;
sx = 10.0;
sy = 10.0;
theta = 45.0;
Peak = 2.0;
baseline  = 0.2;

% Inhibitory influence of the antipreferred stimuli S1 and S2
A1 =1.4;
s_inhib = 20.0;
A2 = 1.4;

x_s1 = -15.0;
y_s1 = 0.0;

x_s2 = 15.0;
y_s2 = 0.0;

% Amplitude and variance of the feedback signal
Ap = 2.0;
sp = 15.0;

params = [cx, cy, sx, sy, theta, Peak, baseline, A1, s_inhib, A2, Ap, sp];

x_min = -60;
x_max = 60;
y_min = -60;
y_max = 60;

Nb_samples = 500;
[X_mesh, Y_mesh] = meshgrid(linspace(x_min,x_max,Nb_samples), linspace(y_min,y_max,Nb_samples));

% Let's say the unmodulated response is when attention is in (-35,35)
x_att_unmod = -35.0;
y_att_unmod =  35.0;

unmod_responses = mod_Response(X_mesh, Y_mesh, [x_att_unmod, y_att_unmod], [x_s1, y_s1], [x_s2,y_s2], horzcat(params(1:10),[0.0,0.1]));
mod_responses_s1 = mod_Response(X_mesh, Y_mesh, [x_s1, y_s1], [x_s1, y_s1], [x_s2, y_s2], params);
mod_responses_s2 = mod_Response(X_mesh, Y_mesh, [x_s2, y_s2], [x_s1, y_s1], [x_s2, y_s2], params);

scrsz = get(0,'ScreenSize');
figure('Position',[1 scrsz(4) scrsz(3) scrsz(4)], 'Color','w');

% Plot the unmodulated response
subplot(2,3,1);
imagesc(X_mesh(1,:), Y_mesh(:,1), unmod_responses);
rectangle('Position',[x_s1-2 y_s1-2 2 2],'Facecolor','w','Linewidth',2)
rectangle('Position',[x_s2-2 y_s2-2 2 2],'Facecolor','w','Linewidth',2)
rectangle('Position',[x_att_unmod-2 y_att_unmod-2 2 2],'Facecolor','r','Linewidth',2)
colorbar;
set(gca,'ydir','normal');
daspect([1 1 1]);
title('Attend away response','Fontsize',16)
set(gca,'Fontsize',16);

% Plot the response when attending to S1
subplot(2,3,2);
imagesc(X_mesh(1,:), Y_mesh(:,1), mod_responses_s1);
% Put some lines to indicate the position of attention and S1
rectangle('Position',[x_s1-2 y_s1-2 2 2],'Facecolor','r','Linewidth',2)
rectangle('Position',[x_s2-2 y_s2-2 2 2],'Facecolor','w','Linewidth',2)
xlim([x_min x_max])
ylim([y_min y_max])
colorbar;
set(gca,'ydir','normal');
daspect([1 1 1]);
title('Attend S1 response','Fontsize',16)
set(gca,'Fontsize',16);

% Plot the response when attending to S2
subplot(2,3,3);
imagesc(X_mesh(1,:), Y_mesh(:,1), mod_responses_s2);
% Put some lines to indicate the position of attention and S1
rectangle('Position',[x_s1-2 y_s1-2 2 2],'Facecolor','w','Linewidth',2)
rectangle('Position',[x_s2-2 y_s2-2 2 2],'Facecolor','r','Linewidth',2)
xlim([x_min x_max])
ylim([y_min y_max])
colorbar;
set(gca,'ydir','normal');
daspect([1 1 1]);
title('Attend S2 response','Fontsize',16)
set(gca,'Fontsize',16);

% Plot the difference Attend S1 , Attend away
subplot(2,3,4)
imagesc(X_mesh(1,:), Y_mesh(:,1), mod_responses_s1 - unmod_responses);
% Put some lines to indicate the position of attention and S1
rectangle('Position',[x_s1-2 y_s1-2 2 2],'Facecolor','r','Linewidth',2)
rectangle('Position',[x_s2-2 y_s2-2 2 2],'Facecolor','w','Linewidth',2)
xlim([x_min x_max])
ylim([y_min y_max])
colorbar;
set(gca,'ydir','normal');
[cmin cmax] = get_caxis(mod_responses_s1 - mod_responses_s2);
caxis([cmin cmax]);
daspect([1 1 1]);
title('Attend S1 - Attend away','Fontsize',16)
set(gca,'Fontsize',16);

% Plot the difference Attend S2 , Attend away
subplot(2,3,5)
imagesc(X_mesh(1,:), Y_mesh(:,1), mod_responses_s2 - unmod_responses);
% Put some lines to indicate the position of attention and S2
rectangle('Position',[x_s1-2 y_s1-2 2 2],'Facecolor','w','Linewidth',2)
rectangle('Position',[x_s2-2 y_s2-2 2 2],'Facecolor','r','Linewidth',2)
xlim([x_min x_max])
ylim([y_min y_max])
colorbar;
set(gca,'ydir','normal');
[cmin cmax] = get_caxis(mod_responses_s1 - mod_responses_s2);
caxis([cmin cmax]);
daspect([1 1 1]);
title('Attend S2 - Attend away','Fontsize',16)
set(gca,'Fontsize',16);

% Plot the difference Attend S1 , Attend S2
subplot(2,3,6);
imagesc(X_mesh(1,:), Y_mesh(:,1), mod_responses_s2 - mod_responses_s1);
% Put some lines to indicate the position of S1 and S2
rectangle('Position',[x_s1-2 y_s1-2 2 2],'Facecolor','w','Linewidth',2)
rectangle('Position',[x_s2-2 y_s2-2 2 2],'Facecolor','w','Linewidth',2)
xlim([x_min x_max])
ylim([y_min y_max])
colorbar;
set(gca,'ydir','normal');
[cmin cmax] = get_caxis(mod_responses_s2 - mod_responses_s1);
caxis([cmin cmax]);
daspect([1 1 1]);
title('Attend s2 - Attend s1','Fontsize',16)
set(gca,'Fontsize',16);

% Plot the difference Attend S1 , Attend S2
figure;
imagesc(X_mesh(1,:), Y_mesh(:,1), mod_responses_s2 - mod_responses_s1);
% Put some lines to indicate the position of S1 and S2
rectangle('Position',[x_s1-2 y_s1-2 2 2],'Facecolor','w','Linewidth',2)
rectangle('Position',[x_s2-2 y_s2-2 2 2],'Facecolor','w','Linewidth',2)
xlim([x_min x_max])
ylim([y_min y_max])
colorbar;
set(gca,'ydir','normal');
[cmin cmax] = get_caxis(mod_responses_s2 - mod_responses_s1);
caxis([cmin cmax]);
daspect([1 1 1]);
title('Attend s2 - Attend s1','Fontsize',16)
set(gca,'Fontsize',16);
colormap(load('colormapAnton2D.dat'))

x_positions = linspace(x_min, x_max, 400);
y_positions = zeros(1,400);

unmod_responses = mod_Response(x_positions, y_positions, [x_att_unmod, y_att_unmod], [x_s1, y_s1], [x_s2,y_s2], params);
mod_responses_s1 = mod_Response(x_positions, y_positions, [x_s1, y_s1], [x_s1, y_s1], [x_s2, y_s2], params);
mod_responses_s2 = mod_Response(x_positions, y_positions, [x_s2, y_s2], [x_s1, y_s1], [x_s2, y_s2], params);

figure;
hold on;
plot(x_positions, unmod_responses,'k','Linewidth',2);
plot(x_positions, mod_responses_s2-mod_responses_s1,'k--','Linewidth',2);
title('Slice along the S1-S2 axis of the difference map Attend S2 - Attend S1');


