% In this script, we test the responses obtained with a divisive inhibition
% model where attention multiplicatively scales the drives from the probe
% and the antipreferred stimuli (we consider only one antipreferred
% stimulus, see the version in 2D for 2 stimuli)

% This shows a shift of the receptive field and a suppression of the flank
% when attention gets closer to the antipreferred stimulus


mygauss = @(A,s,cx,x) A * exp(-(x - cx).^2 / (2.0 * s^2));

nb_probes = 300;
x_min = -100;
x_max = 100;

x_probes = linspace(x_min,x_max, nb_probes);

% Unmodulated RF 
cx = 0.0;
Peak = 2.0;
s_unmod = 15.0;
baseline = 0.1;

% Peak of the inhibitory influence of the antipreferred stimulus
A1 = 1.5;
% Position of the antipreferred stimulus
x_s1 = 20.0;

% Position of attention for attend in
x_att_in = 20.0;
% Position of attention for attend away
x_att_out = -1000.0;
% Variance of the attentional signal
s_att = 20.0;
% Amplitude of the attentional signal
A_att = 2.0;

%% Inhibition modulated by the firing rate

model_response = @(x_attention) (mygauss(Peak, s_unmod, cx,x_probes).*(1.0 + mygauss(A_att, s_att, x_attention,x_probes)) + baseline) ...
      ./ ( 1.0 + A1*(1.0 + mygauss(A_att, s_att, x_attention, x_s1)));    
  
unmod_rf_size = s_unmod * sqrt(2 * log(2));
max_attend_away = max(model_response(x_att_out));
% Plot a sample of unmodulated, modulated, and diff responses
figure;
hold on;
plot(x_probes/unmod_rf_size, model_response(x_att_out)/max_attend_away, 'k','Linewidth',2);
plot(x_probes/unmod_rf_size, model_response(x_att_in)/max_attend_away,'k--','Linewidth',2);
plot(x_probes/unmod_rf_size, (model_response(x_att_in) - model_response(x_att_out))/max_attend_away, 'k-.','Linewidth',2);
legend('unmod','mod','mod - unmod');
ylim_old = ylim();
line([x_att_in/unmod_rf_size x_att_in/unmod_rf_size], [ylim_old(1) ylim_old(2)], 'Linestyle', '--','Color','k','Linewidth',1)
set(gca,'Fontsize',20);

% Then vary the position of attention and show the modification of the RF
figure;
% Record the movie
att_pos = linspace(x_min, x_max, 100);
for j = 1:100 
    x_att = att_pos(j);

    unmod = model_response(x_att_out);  
    mod   = model_response(x_att); 
    
    clf
    hold on;
    plot(x_probes, unmod,'k','Linewidth',2);
    plot(x_probes, mod,'k--','Linewidth',2);
    
    ylim([0.0 2.5])
    ylim_old = ylim();
    line([x_att x_att], [ylim_old(1) ylim_old(2)], 'Linestyle', '--','Color','k','Linewidth',1) ;
    line([x_s1 x_s1], [ylim_old(1) ylim_old(2)], 'Linestyle', '--','Color','k','Linewidth',1) ;
    
    legend('unmod','mod','att pos.','antipref. stim.');    
    F(j) = getframe;
    hold off;
    
    %subplot(2,1,2);
    %clf
    %plot(x_probes, mod - unmod);    

end
% Play the movie

movie(F,10)



